This dataset, english_football, is a data frame containing results for English soccer games in the top 4 tiers from the 1888/89 season to the 2021/22 season. It includes information on match dates, seasons, home and visiting teams, full-time scores, goals scored, division, tier, and match outcomes.
Usage
data(english_football)Format
A data frame with 203956 observations and 12 variables:
- Date
Character vector indicating the date of the match
- Season
Numeric vector indicating the season
- home
Character vector indicating the home team
- visitor
Character vector indicating the visiting team
- FT
Character vector indicating the full-time score
- hgoal
Integer vector indicating the number of goals scored by the home team
- vgoal
Integer vector indicating the number of goals scored by the visiting team
- division
Character vector indicating the division
- tier
Numeric vector indicating the tier
- totgoal
Integer vector indicating the total number of goals scored in the match
- goaldif
Integer vector indicating the goal difference
- result
Character vector indicating the match result