This dataset, italian_football, is a data frame containing results for Italian soccer games in the top tier from the 1934/35 season to the 2021/22 season. It includes information on match dates, seasons, home and visiting teams, full-time scores, and goals scored.
Usage
data(italian_football)Format
A data frame with 27684 observations and 8 variables:
- Date
Date vector indicating the date of the match
- Season
Numeric vector indicating the season
- home
Character vector indicating the home team
- visitor
Character vector indicating the visiting team
- FT
Character vector indicating the full-time score
- hgoal
Integer vector indicating the number of goals scored by the home team
- vgoal
Integer vector indicating the number of goals scored by the visiting team
- tier
Numeric vector indicating the tier