This dataset, pga_results, is a data frame containing player-level results and performance statistics from PGA Tour tournaments. It includes information on tournament and player identifiers, scoring, fantasy points (DraftKings, FanDuel, and SuperDraft), cut status, finishing position, tournament details such as course, date, purse and season, and strokes gained statistics across different aspects of the game.
Usage
data(pga_results)Format
A data frame with 3676 observations and 34 variables:
- Player_initial_last
Character vector indicating the player's name in initial-last format
- tournament.id
Integer vector indicating the tournament identification number
- player.id
Integer vector indicating the player identification number
- hole_par
Integer vector indicating the par for the hole
- strokes
Integer vector indicating the number of strokes taken
- hole_DKP
Numeric vector indicating the DraftKings points earned per hole
- hole_FDP
Numeric vector indicating the FanDuel points earned per hole
- hole_SDP
Integer vector indicating the SuperDraft points earned per hole
- streak_DKP
Integer vector indicating the DraftKings streak bonus points
- streak_FDP
Numeric vector indicating the FanDuel streak bonus points
- streak_SDP
Integer vector indicating the SuperDraft streak bonus points
- n_rounds
Integer vector indicating the number of rounds played
- made_cut
Integer vector indicating whether the player made the cut
- pos
Integer vector indicating the player's finishing position
- finish_DKP
Integer vector indicating the DraftKings points earned for finishing position
- finish_FDP
Integer vector indicating the FanDuel points earned for finishing position
- finish_SDP
Integer vector indicating the SuperDraft points earned for finishing position
- total_DKP
Numeric vector indicating the total DraftKings points earned
- total_FDP
Numeric vector indicating the total FanDuel points earned
- total_SDP
Integer vector indicating the total SuperDraft points earned
- player
Character vector indicating the full name of the player
- tournament.name
Character vector indicating the name of the tournament
- course
Character vector indicating the name of the golf course
- date
Character vector indicating the date of the tournament
- purse
Numeric vector indicating the total prize money offered at the tournament
- season
Integer vector indicating the season or year of the tournament
- no_cut
Integer vector indicating whether the tournament had no cut
- Finish
Character vector indicating the player's final finishing position
- sg_putt
Numeric vector indicating strokes gained putting
- sg_arg
Numeric vector indicating strokes gained around the green
- sg_app
Numeric vector indicating strokes gained approach
- sg_ott
Numeric vector indicating strokes gained off the tee
- sg_t2g
Numeric vector indicating strokes gained tee to green
- sg_total
Numeric vector indicating total strokes gained